"""
    FILE: app.py
    ------------
    This file defines a Flask server for 
    the grocery store app.
"""

# TODO:
# we need a connection to MySQL database
# HTTP verbs
# GET, POST, PUT, UPDATE, DELETE...
# GET product info
# DELETE a product if no longer available
# POST/UPDATE information about a purchased product
# 
# What we are actually going to implement:
#  1. GET all the products in our table
#  2. POST to add items to a shopping cart;

from flask import Flask, request, jsonify, render_template
import pymysql.cursors

import config

# CONSTANTS
QUANTITY_ROW = 4

# Configure MySQL
conn = pymysql.connect(
    user=config.USERNAME,
    database=config.DATABASE,
    password=config.PASSWORD
)

app = Flask(__name__)

# Routes
@app.route('/')
def index():
    return render_template('index.html')

@app.route('/products', methods=['GET'])
def products():
    if request.method == 'GET':
        cur = conn.cursor()
        cur.execute("SELECT * FROM products;")
        data = cur.fetchall() # data is a list
        cur.close()
        return jsonify(products=data)

@app.route('/products/<product_id>', methods=['POST'])
def add_to_shopping_cart(product_id):
    if request.method == 'POST':
        cur = conn.cursor()
        request_data = request.json # request_data is a dict
        cur.execute("SELECT * FROM products WHERE id = %s", request_data["productId"])
        data = cur.fetchone()
        quantity = data[QUANTITY_ROW]
        cur.execute("UPDATE products SET quantity = %s WHERE id = %s", (quantity - 1, request_data["productId"]))
        conn.commit()
        cur.close()
        return jsonify(message="Product added to cart successfully", product=data), 200

if __name__ == '__main__':
    app.run(debug=True)
